@@ -28,17 +28,18 @@ async function test() {
   let bus = new elbus.Client("js");
   bus.on_disconnect = disconnected;
   bus.on_frame = on_frame;
+  //await bus.connect(("localhost", 9924));
   await bus.connect("/tmp/elbus.sock");
-  let frame = new elbus.Frame(elbus.OP_SUBSCRIBE, 1);
-  frame.topic = ["tests", "xxz"];
-  //frame.topic = "xxxz";
-  let op = await bus.send(frame);
+  let op = await bus.subscribe(["tests", "xxz"]);
   console.log(await op.wait_completed());
-  //while (true) {
+  op = await bus.unsubscribe(["tests", "xxz"]);
+  console.log(await op.wait_completed());
+  //while (bus.is_connected()) {
   //console.log(bus.is_connected());
   //await sleep(1000);
   //}
-  let iters = 100_000;
+  //return;
+  let iters = 200_000;
   let msg = new elbus.Frame(elbus.OP_MESSAGE, 0);
   msg.payload = Buffer.from("hello");
   let start = new Date().getTime() / 1000;
@@ -51,7 +52,7 @@ async function test() {
   let speed = Math.round(iters / elapsed);
   console.log(speed, "iters/s");
   console.log(Math.round(1_000_000 / speed), "us per iter");
-  bus.disconnect();
+  await bus.disconnect();
 }
 
 test();
