@@ -1,7 +1,4 @@
 // TODO bus rpc: stats
-// TODO tests
-// TODO rpc tests
-// TODO release
 use std::fmt;
 use std::sync::Arc;
 
@@ -398,7 +395,7 @@ pub mod common;
 pub mod broker;
 #[cfg(feature = "ipc")]
 pub mod ipc;
-#[cfg(any(feature = "rpc", feature = "broker-api"))]
+#[cfg(feature = "rpc")]
 pub mod rpc;
 
 #[cfg(any(feature = "rpc", feature = "broker", feature = "ipc"))]
